==> jei-1.20-fabric-14.0.0.4-sources.jar: mezz/jei/library/plugins/vanilla/crafting/replacers/SuspiciousStewRecipeMaker.java <==
package mezz.jei.library.plugins.vanilla.crafting.replacers;

import mezz.jei.api.constants.ModIds;
import net.minecraft.class_1291;
import net.minecraft.class_1747;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1830;
import net.minecraft.class_1856;
import net.minecraft.class_1867;
import net.minecraft.class_2246;
import net.minecraft.class_2356;
import net.minecraft.class_2371;
import net.minecraft.class_2960;
import net.minecraft.class_3489;
import net.minecraft.class_3955;
import net.minecraft.class_6880;
import net.minecraft.class_6885.class_6887;
import net.minecraft.class_7710;
import net.minecraft.class_7923;
import java.util.List;

public final class SuspiciousStewRecipeMaker {

	public static List<class_3955> createRecipes() {
		String group = "jei.suspicious.stew";
		class_1856 brownMushroom = class_1856.method_8091(class_2246.field_10251.method_8389());
		class_1856 redMushroom = class_1856.method_8091(class_2246.field_10559.method_8389());
		class_1856 bowl = class_1856.method_8091(class_1802.field_8428);

		return class_7923.field_41178.method_40266(class_3489.field_15543)
			.stream()
			.flatMap(class_6887::method_40239)
			.map(class_6880::comp_349)
			.filter(class_1747.class::isInstance)
			.map(item -> ((class_1747) item).method_7711())
			.filter(class_2356.class::isInstance)
			.map(class_2356.class::cast)
			.<class_3955>map(flowerBlock -> {
				class_1856 flower = class_1856.method_8091(flowerBlock.method_8389());
				class_2371<class_1856> inputs = class_2371.method_10212(class_1856.field_9017, brownMushroom, redMushroom, bowl, flower);
				class_1799 output = new class_1799(class_1802.field_8766, 1);
				class_1291 mobeffect = flowerBlock.method_10188();
				class_1830.method_8021(output, mobeffect, flowerBlock.method_10187());
				class_2960 id = new class_2960(ModIds.MINECRAFT_ID, "jei.suspicious.stew." + flowerBlock.method_9539());
				return new class_1867(id, group, class_7710.field_40251, output, inputs);
			})
			.toList();
	}

	private SuspiciousStewRecipeMaker() {

	}
}

==> jei-1.21.1-fabric-19.22.1.316-sources.jar: mezz/jei/library/plugins/vanilla/crafting/replacers/SuspiciousStewRecipeMaker.java <==
package mezz.jei.library.plugins.vanilla.crafting.replacers;

import mezz.jei.api.constants.ModIds;
import mezz.jei.common.util.RegistryUtil;
import net.minecraft.class_1747;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1856;
import net.minecraft.class_1867;
import net.minecraft.class_2246;
import net.minecraft.class_2356;
import net.minecraft.class_2371;
import net.minecraft.class_2960;
import net.minecraft.class_3489;
import net.minecraft.class_3955;
import net.minecraft.class_6880;
import net.minecraft.class_6885.class_6887;
import net.minecraft.class_7710;
import net.minecraft.class_7924;
import net.minecraft.class_8786;
import net.minecraft.class_9334;
import java.util.List;

public final class SuspiciousStewRecipeMaker {

	public static List<class_8786<class_3955>> createRecipes() {
		String group = "jei.suspicious.stew";
		class_1856 brownMushroom = class_1856.method_8091(class_2246.field_10251.method_8389());
		class_1856 redMushroom = class_1856.method_8091(class_2246.field_10559.method_8389());
		class_1856 bowl = class_1856.method_8091(class_1802.field_8428);

		return RegistryUtil.getRegistry(class_7924.field_41197)
			.method_40266(class_3489.field_15543)
			.stream()
			.flatMap(class_6887::method_40239)
			.map(class_6880::comp_349)
			.filter(class_1747.class::isInstance)
			.map(item -> ((class_1747) item).method_7711())
			.filter(class_2356.class::isInstance)
			.map(class_2356.class::cast)
			.map(flowerBlock -> {
				class_1856 flower = class_1856.method_8091(flowerBlock.method_8389());
				class_2371<class_1856> inputs = class_2371.method_10212(class_1856.field_9017, brownMushroom, redMushroom, bowl, flower);
				class_1799 output = new class_1799(class_1802.field_8766, 1);
				var effects = flowerBlock.method_53233();
				output.method_57379(class_9334.field_49652, effects);
				class_2960 id = class_2960.method_60655(ModIds.MINECRAFT_ID, "jei.suspicious.stew." + flowerBlock.method_9539());
				class_3955 recipe = new class_1867(group, class_7710.field_40251, output, inputs);
				return new class_8786<>(id, recipe);
			})
			.toList();
	}

	private SuspiciousStewRecipeMaker() {

	}
}
